@@ -47,10 +47,10 @@ class FireWall(object):
 
 		# do.
 		output = utils.__execute__(["sudo", "ufw", "allow", str(port)])
-		if "Rule updated" in output or "Skipping adding existing rule" in output:
+		if "Rule updated" in output or "Rules updated" in output or "Skipping adding existing rule" in output:
 			return r3sponse.success_response(f"Successfully allowed port [{port}].")
 		else:
-			return r3sponse.error_response(f"Failed to allow port [{port}].")
+			return r3sponse.error_response(f"Failed to allow port [{port}], output: [{output}].")
 
 		#
 	def deny(self, port):
@@ -62,10 +62,10 @@ class FireWall(object):
 
 		# do.
 		output = utils.__execute__(["sudo", "ufw", "deny", str(port)])
-		if "Rule updated" in output or "Skipping adding existing rule" in output:
+		if "Rule updated" in output or "Rules updated" in output or "Skipping adding existing rule" in output:
 			return r3sponse.success_response(f"Successfully denied port [{port}].")
 		else:
-			return r3sponse.error_response(f"Failed to deny port [{port}].")
+			return r3sponse.error_response(f"Failed to deny port [{port}], output: [{output}].")
 
 		#
 	def allow_all(self):
@@ -131,7 +131,7 @@ class FireWall(object):
 
 		# retrieve.
 		output = utils.__execute__(["sudo", "ufw", "status"])
-		print(f"Output: [{output}].")
+		#print(f"Output: [{output}].")
 
 		# get status.
 		status = "unkown"
